@@ -1,7 +1,7 @@
 package App::ListOrgHeadlines;
 
-our $DATE = '2016-01-18'; # DATE
-our $VERSION = '0.35'; # VERSION
+our $DATE = '2016-03-23'; # DATE
+our $VERSION = '0.36'; # VERSION
 
 use 5.010001;
 use strict;
@@ -380,7 +380,7 @@ sub list_org_headlines {
         $res = [map {$_->[0]} @res];
     }
 
-    [200, "OK", $res, {format_options=>{"any"=> {list_max_columns=>1}}}];
+    [200, "OK", $res];
 }
 
 1;
@@ -398,7 +398,7 @@ App::ListOrgHeadlines - List all headlines in all Org files
 
 =head1 VERSION
 
-This document describes version 0.35 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2016-01-18.
+This document describes version 0.36 of App::ListOrgHeadlines (from Perl distribution App-OrgUtils), released on 2016-03-23.
 
 =head1 SYNOPSIS
 
@@ -554,7 +554,7 @@ Please visit the project's homepage at L<https://metacpan.org/release/App-OrgUti
 
 =head1 SOURCE
 
-Source repository is at L<https://github.com/sharyanto/perl-App-OrgUtils>.
+Source repository is at L<https://github.com/perlancar/perl-App-OrgUtils>.
 
 =head1 BUGS
 
